/*
main.c
For the NU32 PIC32 Board
Example code for how to write to an HD44780 LCD in 4bit mode with no reading back data
*/

#include "Compiler.h"			// tells MPLAB which compiler to use
#include "HardwareProfile.h"    // info on how the PIC is used, based on the constant you defined above
#include "LCD.h"
#define SYS_FREQ (80000000L)    // system clock is 80 MHz

void main(void)
{
  SYSTEMConfigPerformance(SYS_FREQ);  // tell PIC its operating frequency
  mInitAllLEDs();                    // initialize LED pins, defined in HardwareProfile_NU32.h

  lcd_init();  // initialize the HD44780 LCD in 4 bit mode, do this immediately after power up

  putsLCD("Hello World!");
  Delayms(1000);
  putsLCD("\fHi"); // "\f" clears the screen and goes to the first position on the first line
  lcd_gotoxy(3,2); // move cursor to x,y
  putsLCD("there");
  Delayms(1000);
  putsLCD("\f\nTest this"); // "\n" goes to the next line
  Delayms(500);
  putsLCD("\bA"); // "\b" moves the cursor back one position
  Delayms(1000);
  putsLCD("\f");
  
  // this is how you write the contents of a variable
  char buffer[5]; // this will store the string
  int n; // this is the number of characters in the string after it has been converted
  short a = 10; // the number we will convert to a string
  n=sprintf(buffer, "%d", a); // make the string and see how many characters there are
  putsLCD("a = "); // write some text
  putsLCD(buffer);  // write the contents of the variable

  while(1) {                         // loop forever
    if(swUser) {                     // swUser is high (true) until pressed
      mLED_0_Off();
      mLED_1_On();
      mLED_2_Off();
      mLED_3_On();
    }
    else {                           // swUser is low (false) if pressed
      mLED_0_On();
      mLED_1_Off();
      mLED_2_On();
      mLED_3_Off(); 
    }

    a--; // change the variable and write it to the LCD
    n=sprintf(buffer, "%d", a);
    putsLCD("\fa = ");
    putsLCD(buffer);
    Delayms(500);

  }                                  // end of while loop
}                                    // end of main.c


